package net.rutles.mygallery;

import java.io.File;
import java.util.ArrayList;
import java.util.List;

import android.app.Activity;
import android.app.AlertDialog;
import android.content.DialogInterface;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.os.Bundle;
import android.os.Debug;
import android.os.Environment;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.AdapterView.OnItemClickListener;
import android.widget.BaseAdapter;
import android.widget.Gallery;
import android.widget.ImageView;
import android.widget.Toast;

public class MyGallery extends Activity 
	implements
	DialogInterface.OnClickListener,
	OnItemClickListener{
	
	private ImageView imageView;
	private Gallery gallery;
	private String[] picturesList;
	private String picturesPath;
	
	/** Called when the activity is first created. */
	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.main);

		if(!sdcardReadReady()){
			new AlertDialog.Builder(this)
			.setTitle(R.string.app_name)
			.setMessage(R.string.message2)
			.setNeutralButton("OK", this)
			.show();
			return;
		}

		String rootDir = Environment.getExternalStorageDirectory().getPath();
		File picturesDir = new File(rootDir + "/Pictures");
		
		if(!picturesDir.exists()){
			new AlertDialog.Builder(this)
			.setTitle(R.string.app_name)
			.setMessage(R.string.message3)
			.setNeutralButton("OK", this)
			.show();
			return;
		}

		picturesPath = picturesDir.getAbsolutePath() + "/";
		picturesList = picturesDir.list();
		
		List<String> tmp = new ArrayList<String>();
		for(String s: picturesList){
			if(s.endsWith("JPG") || s.endsWith("jpg")){
				tmp.add(s);
			}
		}
		tmp.toArray(picturesList);

		gallery = (Gallery)findViewById(R.id.Gallery01);
		gallery.setSpacing(2);
		gallery.setAdapter(new GalleryAdapter());
		gallery.setOnItemClickListener(this);
	
		imageView = (ImageView)findViewById(R.id.ImageView01);
		Bitmap picture = BitmapFactory.decodeFile(
			picturesPath + picturesList[0]);
		imageView.setImageBitmap(picture);
	}

	private boolean sdcardReadReady(){
		String state = Environment.getExternalStorageState();
		return (
		Environment.MEDIA_MOUNTED.equals(state) || 
		Environment
		.MEDIA_MOUNTED_READ_ONLY.equals(state)
		);
	}
	
	@Override
	public void onClick(DialogInterface arg0, int arg1) {
		// TODO Auto-generated method stub
		switch(arg1){
		case DialogInterface.BUTTON_NEUTRAL:
			arg0.dismiss();
			finish();
		}
	}

	public class GalleryAdapter extends BaseAdapter{

		@Override
		public int getCount() {
			// TODO Auto-generated method stub
			return picturesList.length;
		}

		@Override
		public Object getItem(int position) {
			// TODO Auto-generated method stub
			return null;
		}

		@Override
		public long getItemId(int position) {
			// TODO Auto-generated method stub
			return 0;
		}

		@Override
		public View getView(int arg0, View arg1, ViewGroup arg2) {
			// TODO Auto-generated method stub
			ImageView view;
			if (arg1==null) {
				view = new ImageView(MyGallery.this);
				view.setImageBitmap(this.getImage(arg0));
			} else {
				view=(ImageView)arg1;
			}
			return view;
		}
		
		private Bitmap getImage(int n){
			Bitmap thumbnail;
			BitmapFactory.Options options = new BitmapFactory.Options();
			options.inJustDecodeBounds = true;
			BitmapFactory.decodeFile(
					picturesPath + picturesList[n], options);

			int width = options.outWidth;
			int height = options.outHeight;
			int scale = Math.max(width / 160 + 1, height / 120 + 1);
			options.inSampleSize = scale;

			options.inJustDecodeBounds = false;
			thumbnail = BitmapFactory.decodeFile(
					picturesPath + picturesList[n], options);
			return thumbnail;
		}

		
	}

	
	@Override
	public void onItemClick(AdapterView<?> arg0, View arg1, int arg2, long arg3) {
		// TODO Auto-generated method stub
		if(arg0 == gallery){
			Bitmap picture = BitmapFactory.decodeFile(
				picturesPath + picturesList[arg2]);
			imageView.setImageBitmap(picture);

			String free =
				"Free: " + 
				(Debug.getNativeHeapFreeSize() / 1024) +
				"Kbytes";
			Toast.makeText(this, free, Toast.LENGTH_LONG).show();
		}
	}
}